==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/LinkedIntegrationRuntimeKeyAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The key authorization type integration runtime.
 * @property authorizationType The authorization type for integration runtime sharing.
 * Expected value is 'Key'.
 * @property key The key used for authorization.
 */
public data class LinkedIntegrationRuntimeKeyAuthorizationArgs(
    public val authorizationType: Output<String>,
    public val key: Output<SecureStringArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs =
        com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs.builder()
            .authorizationType(authorizationType.applyValue({ args0 -> args0 }))
            .key(key.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [LinkedIntegrationRuntimeKeyAuthorizationArgs].
 */
@PulumiTagMarker
public class LinkedIntegrationRuntimeKeyAuthorizationArgsBuilder internal constructor() {
    private var authorizationType: Output<String>? = null

    private var key: Output<SecureStringArgs>? = null

    /**
     * @param value The authorization type for integration runtime sharing.
     * Expected value is 'Key'.
     */
    @JvmName("xcbilewaywgpgfru")
    public suspend fun authorizationType(`value`: Output<String>) {
        this.authorizationType = value
    }

    /**
     * @param value The key used for authorization.
     */
    @JvmName("gpyoedvlrcjyylqr")
    public suspend fun key(`value`: Output<SecureStringArgs>) {
        this.key = value
    }

    /**
     * @param value The authorization type for integration runtime sharing.
     * Expected value is 'Key'.
     */
    @JvmName("yjuhtdsuhgjmukqk")
    public suspend fun authorizationType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizationType = mapped
    }

    /**
     * @param value The key used for authorization.
     */
    @JvmName("wcaulvlfqtntpqom")
    public suspend fun key(`value`: SecureStringArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param argument The key used for authorization.
     */
    @JvmName("cuegpgupbpnpmcrv")
    public suspend fun key(argument: suspend SecureStringArgsBuilder.() -> Unit) {
        val toBeMapped = SecureStringArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.key = mapped
    }

    internal fun build(): LinkedIntegrationRuntimeKeyAuthorizationArgs =
        LinkedIntegrationRuntimeKeyAuthorizationArgs(
            authorizationType = authorizationType ?: throw PulumiNullFieldException("authorizationType"),
            key = key ?: throw PulumiNullFieldException("key"),
        )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/synapse/kotlin/inputs/LinkedIntegrationRuntimeKeyAuthorizationArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.synapse.kotlin.inputs

import com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * The key authorization type integration runtime.
 * @property authorizationType The authorization type for integration runtime sharing.
 * Expected value is 'Key'.
 * @property key The key used for authorization.
 */
public data class LinkedIntegrationRuntimeKeyAuthorizationArgs(
    public val authorizationType: Output<String>,
    public val key: Output<SecureStringArgs>,
) :
    ConvertibleToJava<com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs> {
    override fun toJava():
        com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs =
        com.pulumi.azurenative.synapse.inputs.LinkedIntegrationRuntimeKeyAuthorizationArgs.builder()
            .authorizationType(authorizationType.applyValue({ args0 -> args0 }))
            .key(key.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [LinkedIntegrationRuntimeKeyAuthorizationArgs].
 */
@PulumiTagMarker
public class LinkedIntegrationRuntimeKeyAuthorizationArgsBuilder internal constructor() {
    private var authorizationType: Output<String>? = null

    private var key: Output<SecureStringArgs>? = null

    /**
     * @param value The authorization type for integration runtime sharing.
     * Expected value is 'Key'.
     */
    @JvmName("dphoylllbxpjkjgc")
    public suspend fun authorizationType(`value`: Output<String>) {
        this.authorizationType = value
    }

    /**
     * @param value The key used for authorization.
     */
    @JvmName("rknscdracafsdbro")
    public suspend fun key(`value`: Output<SecureStringArgs>) {
        this.key = value
    }

    /**
     * @param value The authorization type for integration runtime sharing.
     * Expected value is 'Key'.
     */
    @JvmName("biwdyacmtkgstlew")
    public suspend fun authorizationType(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.authorizationType = mapped
    }

    /**
     * @param value The key used for authorization.
     */
    @JvmName("rtphjerdhbplgfnd")
    public suspend fun key(`value`: SecureStringArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param argument The key used for authorization.
     */
    @JvmName("klftmghuqtyjqwms")
    public suspend fun key(argument: suspend SecureStringArgsBuilder.() -> Unit) {
        val toBeMapped = SecureStringArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.key = mapped
    }

    internal fun build(): LinkedIntegrationRuntimeKeyAuthorizationArgs =
        LinkedIntegrationRuntimeKeyAuthorizationArgs(
            authorizationType = authorizationType ?: throw PulumiNullFieldException("authorizationType"),
            key = key ?: throw PulumiNullFieldException("key"),
        )
}
